Documentation
¶
Overview ¶
+groupName=applicationconnector.kyma-project.io
Index ¶
- Variables
- func Resource(resource string) schema.GroupResource
- type Application
- func (in *Application) DeepCopy() *Application
- func (in *Application) DeepCopyInto(out *Application)
- func (in *Application) DeepCopyObject() runtime.Object
- func (app Application) GetApplicationID() string
- func (pw *Application) GetObjectKind() schema.ObjectKind
- func (app *Application) HasFinalizer(finalizer string) bool
- func (app *Application) RemoveFinalizer(finalizer string)
- func (app *Application) SetAccessLabel()
- func (app *Application) SetFinalizer(finalizer string)
- func (app *Application) SetInstallationStatus(status InstallationStatus)
- func (app Application) ShouldSkipInstallation() bool
- type ApplicationList
- type ApplicationSpec
- type ApplicationStatus
- type Authentication
- type CSRFInfo
- type CompassMetadata
- type Credentials
- type Entry
- type InstallationStatus
- type Service
Constants ¶
This section is empty.
Variables ¶
var ( // localSchemeBuilder and AddToScheme will stay in k8s.io/kubernetes. SchemeBuilder runtime.SchemeBuilder AddToScheme = localSchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: "applicationconnector.kyma-project.io", Version: "v1alpha1"}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type Application ¶
type Application struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata"`
Spec ApplicationSpec `json:"spec"`
Status ApplicationStatus `json:"status,omitempty"`
}
func (*Application) DeepCopy ¶
func (in *Application) DeepCopy() *Application
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Application.
func (*Application) DeepCopyInto ¶
func (in *Application) DeepCopyInto(out *Application)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Application) DeepCopyObject ¶
func (in *Application) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (Application) GetApplicationID ¶
func (app Application) GetApplicationID() string
func (*Application) GetObjectKind ¶
func (pw *Application) GetObjectKind() schema.ObjectKind
func (*Application) HasFinalizer ¶
func (app *Application) HasFinalizer(finalizer string) bool
func (*Application) RemoveFinalizer ¶
func (app *Application) RemoveFinalizer(finalizer string)
func (*Application) SetAccessLabel ¶
func (app *Application) SetAccessLabel()
func (*Application) SetFinalizer ¶
func (app *Application) SetFinalizer(finalizer string)
func (*Application) SetInstallationStatus ¶
func (app *Application) SetInstallationStatus(status InstallationStatus)
func (Application) ShouldSkipInstallation ¶
func (app Application) ShouldSkipInstallation() bool
type ApplicationList ¶
type ApplicationList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []Application `json:"items"`
}
func (*ApplicationList) DeepCopy ¶
func (in *ApplicationList) DeepCopy() *ApplicationList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApplicationList.
func (*ApplicationList) DeepCopyInto ¶
func (in *ApplicationList) DeepCopyInto(out *ApplicationList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ApplicationList) DeepCopyObject ¶
func (in *ApplicationList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ApplicationSpec ¶
type ApplicationSpec struct {
Description string `json:"description"`
SkipInstallation bool `json:"skipInstallation,omitempty"`
Services []Service `json:"services"`
Labels map[string]string `json:"labels"`
Tenant string `json:"tenant,omitempty"`
Group string `json:"group,omitempty"`
CompassMetadata *CompassMetadata `json:"compassMetadata,omitempty"`
// New fields used by V2 version
Tags []string `json:"tags,omitempty"`
DisplayName string `json:"displayName"`
ProviderDisplayName string `json:"providerDisplayName"`
LongDescription string `json:"longDescription"`
SkipVerify bool `json:"skipVerify"`
EncodeURL bool `json:"encodeUrl"`
// Deprecated
AccessLabel string `json:"accessLabel,omitempty"`
}
ApplicationSpec defines spec section of the Application custom resource
func (*ApplicationSpec) DeepCopy ¶
func (in *ApplicationSpec) DeepCopy() *ApplicationSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApplicationSpec.
func (*ApplicationSpec) DeepCopyInto ¶
func (in *ApplicationSpec) DeepCopyInto(out *ApplicationSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (ApplicationSpec) HasGroup ¶
func (appSpec ApplicationSpec) HasGroup() bool
HasGroup returns true if ApplicationSpec has a non-empty value for Group field set
func (ApplicationSpec) HasTenant ¶
func (appSpec ApplicationSpec) HasTenant() bool
HasTenant returns true if ApplicationSpec has a non-empty value for Tenant field set
type ApplicationStatus ¶
type ApplicationStatus struct {
// Represents the status of Application release installation
InstallationStatus InstallationStatus `json:"installationStatus"`
}
func (*ApplicationStatus) DeepCopy ¶
func (in *ApplicationStatus) DeepCopy() *ApplicationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ApplicationStatus.
func (*ApplicationStatus) DeepCopyInto ¶
func (in *ApplicationStatus) DeepCopyInto(out *ApplicationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Authentication ¶
type Authentication struct {
ClientIds []string `json:"clientIds"`
}
func (*Authentication) DeepCopy ¶
func (in *Authentication) DeepCopy() *Authentication
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Authentication.
func (*Authentication) DeepCopyInto ¶
func (in *Authentication) DeepCopyInto(out *Authentication)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CSRFInfo ¶
type CSRFInfo struct {
TokenEndpointURL string `json:"tokenEndpointURL"`
}
func (*CSRFInfo) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CSRFInfo.
func (*CSRFInfo) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CompassMetadata ¶
type CompassMetadata struct {
ApplicationID string `json:"applicationId"`
Authentication Authentication `json:"authentication"`
}
func (*CompassMetadata) DeepCopy ¶
func (in *CompassMetadata) DeepCopy() *CompassMetadata
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CompassMetadata.
func (*CompassMetadata) DeepCopyInto ¶
func (in *CompassMetadata) DeepCopyInto(out *CompassMetadata)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Credentials ¶
type Credentials struct {
Type string `json:"type"`
SecretName string `json:"secretName"`
AuthenticationUrl string `json:"authenticationUrl,omitempty"`
CSRFInfo *CSRFInfo `json:"csrfInfo,omitempty"`
}
Credentials defines type of authentication and where the credentials are stored
func (*Credentials) DeepCopy ¶
func (in *Credentials) DeepCopy() *Credentials
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Credentials.
func (*Credentials) DeepCopyInto ¶
func (in *Credentials) DeepCopyInto(out *Credentials)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Entry ¶
type Entry struct {
Type string `json:"type"`
TargetUrl string `json:"targetUrl"`
SpecificationUrl string `json:"specificationUrl,omitempty"`
ApiType string `json:"apiType,omitempty"`
Credentials Credentials `json:"credentials,omitempty"`
RequestParametersSecretName string `json:"requestParametersSecretName,omitempty"`
// New fields used by V2 version
Name string `json:"name"`
ID string `json:"id"`
CentralGatewayUrl string `json:"centralGatewayUrl"`
// Deprecated
AccessLabel string `json:"accessLabel,omitempty"`
// Deprecated
GatewayUrl string `json:"gatewayUrl"`
}
Entry defines, what is enabled by activating the service.
func (*Entry) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Entry.
func (*Entry) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type InstallationStatus ¶
type InstallationStatus struct {
Status string `json:"status"`
Description string `json:"description"`
}
func (*InstallationStatus) DeepCopy ¶
func (in *InstallationStatus) DeepCopy() *InstallationStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new InstallationStatus.
func (*InstallationStatus) DeepCopyInto ¶
func (in *InstallationStatus) DeepCopyInto(out *InstallationStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Service ¶
type Service struct {
ID string `json:"id"`
Identifier string `json:"identifier"`
Name string `json:"name"`
DisplayName string `json:"displayName"`
Description string `json:"description"`
Entries []Entry `json:"entries"`
// New fields used by V2 version
AuthCreateParameterSchema *string `json:"authCreateParameterSchema,omitempty"`
// Deprecated
Labels map[string]string `json:"labels,omitempty"`
// Deprecated
LongDescription string `json:"longDescription,omitempty"`
// Deprecated
ProviderDisplayName string `json:"providerDisplayName"`
// Deprecated
Tags []string `json:"tags,omitempty"`
}
Service represents part of the remote environment, which is mapped 1 to 1 in the service-catalog to: - service class in V1 - service plans in V2 (since api-packages support)
func (*Service) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Service.
func (*Service) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.