Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EventActivationLister ¶
type EventActivationLister interface {
// List lists all EventActivations in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.EventActivation, err error)
// EventActivations returns an object that can list and get EventActivations.
EventActivations(namespace string) EventActivationNamespaceLister
EventActivationListerExpansion
}
EventActivationLister helps list EventActivations.
func NewEventActivationLister ¶
func NewEventActivationLister(indexer cache.Indexer) EventActivationLister
NewEventActivationLister returns a new EventActivationLister.
type EventActivationListerExpansion ¶
type EventActivationListerExpansion interface{}
EventActivationListerExpansion allows custom methods to be added to EventActivationLister.
type EventActivationNamespaceLister ¶
type EventActivationNamespaceLister interface {
// List lists all EventActivations in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.EventActivation, err error)
// Get retrieves the EventActivation from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.EventActivation, error)
EventActivationNamespaceListerExpansion
}
EventActivationNamespaceLister helps list and get EventActivations.
type EventActivationNamespaceListerExpansion ¶
type EventActivationNamespaceListerExpansion interface{}
EventActivationNamespaceListerExpansion allows custom methods to be added to EventActivationNamespaceLister.
Click to show internal directories.
Click to hide internal directories.